==> basicshib-3.0.0.tar.gz: basicshib/src/AuthorizationHandler.php <==
<?php

namespace Drupal\basicshib;

use Drupal\basicshib\Plugin\BasicShibPluginManager;
use Drupal\basicshib\Plugin\GrouperPluginInterface;
use Drupal\Core\Config\ConfigFactoryInterface;
use Psr\Log\LoggerInterface;
use Symfony\Component\HttpFoundation\RequestStack;
use Drupal\user\UserInterface;

/**
 *
 */
class AuthorizationHandler implements AuthorizationHandlerInterface {

  use GrouperHelperTrait;

  /**
   * Grouper plugin instance variable.
   *
   * @var GrouperPluginInterface
   */
  private $_grouper;

  /**
   * @var \Drupal\basicshib\SessionTracker
   */
  private SessionTracker $session_tracker;

  /**
   * instance of the ShibLogger logging channel
   *
   * @var \Psr\Log\LoggerInterface
   */
  private LoggerInterface $_shib_logger;

  /**
   * Extended Logging status
   *
   * @var array|mixed|null
   */
  private $logging;

  /**
   * AuthorizationHandler constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   * @param \Symfony\Component\HttpFoundation\RequestStack $request_stack
   * @param \Drupal\basicshib\Plugin\BasicShibPluginManager $grouper_plugin_manager
   * @param \Psr\Log\LoggerInterface $shib_logger
   *
   * @throws \Drupal\Component\Plugin\Exception\PluginException
   */
  public function __construct(ConfigFactoryInterface $config_factory,
        RequestStack $request_stack,
        BasicShibPluginManager $grouper_plugin_manager,
        LoggerInterface $shib_logger
    ) {

    $this->session_tracker = new SessionTracker(
          $request_stack->getCurrentRequest()->getSession()
      );

    $plugins = $config_factory
      ->get('basicshib.settings')
      ->get('plugins');

    // Create instance of grouper plugin.
    $this->_grouper = $grouper_plugin_manager
      ->createInstance($plugins['grouper']);
    $this->logging = $config_factory->get('basicshib.settings')->get('extended_logging');
    $this->_shib_logger = $shib_logger;
  }

  /**
   * @param \Drupal\user\UserInterface $current_account
   *
   * @throws \Drupal\Core\Entity\EntityStorageException
   */
  public function authorize(UserInterface $current_account) {

    if ($this->logging['logging']) {
      $this->_shib_logger->notice('The Grouper authorization process started.');
    }
    // Logs the HTTP request that is user-specific
    // at the time of current login session.
    $user_groups = explode(';', $this->getUserAttribute('isMemberOf'));
    if ($this->logging['logging']) {
      $this->_shib_logger->notice('The Grouper groups retrieved: %groups', ['%groups' => $user_groups]);
    }
    $previous_roles = $current_account->getRoles();
    if ($this->logging['logging']) {
      $this->_shib_logger->notice('The Drupal previous roles: %roles', ['%roles' => $previous_roles]);
    }
    // Get map from GrouperPluginDefault.
    $group_role_map = $this->_grouper->getMap();
    if ($this->logging['logging']) {
      $this->_shib_logger->notice('The Grouper groups role map: %map', ['%map' => $group_role_map]);
    }
    // Remove previous user roles.
    foreach ($previous_roles as $role_id) {
      if (strcmp($role_id, 'administrator') !== 0) {
        $current_account->removeRole($role_id);
      }
    }

    // Assign a role to the current account if user group is mapped to that role.
    foreach ($group_role_map as $group => $role) {
      if (!empty($group) && in_array($group, $user_groups)) {
        $current_account->addRole($role);
      }
    }
    if ($this->logging['logging']) {
      $assigned_roles = $current_account->getRoles();
      $this->_shib_logger->notice('Roles assigned from grouper: %assigned', ['%assigned' => $assigned_roles]);
    }
    $current_account->save();
    if ($this->logging['logging']) {
      $this->_shib_logger->notice('The Drupal roles updated.');
    }
  }

}

==> basicshib-3.0.1.tar.gz: basicshib/src/AuthorizationHandler.php <==
<?php

namespace Drupal\basicshib;

use Drupal\basicshib\Plugin\BasicShibPluginManager;
use Drupal\Core\Config\ConfigFactoryInterface;
use Symfony\Component\HttpFoundation\RequestStack;
use Drupal\user\UserInterface;

/**
 *
 */
class AuthorizationHandler implements AuthorizationHandlerInterface {

  use GrouperHelperTrait;

  /**
   * Grouper plugin instance variable.
   *
   * @var GrouperPluginInterface
   */
  private $_grouper;

  /**
   * AuthorizationHandler constructor.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   * @param \Symfony\Component\HttpFoundation\RequestStack $request_stack
   * @param \Drupal\basicshib\Plugin\BasicShibPluginManager $_grouper_plugin_manager
   *
   * @throws \Drupal\Component\Plugin\Exception\PluginException
   */
  public function __construct(ConfigFactoryInterface $config_factory,
        RequestStack $request_stack,
        BasicShibPluginManager $grouper_plugin_manager
    ) {

    $this->session_tracker = new SessionTracker(
          $request_stack->getCurrentRequest()->getSession()
      );

    $plugins = $config_factory
      ->get('basicshib.settings')
      ->get('plugins');

    // Create instance of grouper plugin.
    $this->_grouper = $grouper_plugin_manager
      ->createInstance($plugins['grouper']);
  }

  /**
   * @param \Drupal\user\Entity\UserInterface $current_account
   *
   * @inheritDoc
   *
   * @return a new role.
   */
  public function authorize(UserInterface $current_account) {

    // Logs the HTTP request that is user-specific
    // at the time of current login session.
    $user_groups = explode(';', $this->getUserAttribute('isMemberOf'));
    $previous_roles = $current_account->getRoles();

    // Get map from GrouperPluginDefault.
    $group_role_map = $this->_grouper->getMap();

    // Remove previous user roles.
    foreach ($previous_roles as $role_id) {
      if (strcmp($role_id, 'administrator') !== 0) {
        $current_account->removeRole($role_id);
      }
    }

    // Assign a role to the current account if user group is mapped to that role.
    foreach ($group_role_map as $group => $role) {
      if (!empty($group) && in_array($group, $user_groups)) {
        $current_account->addRole($role);
      }
    }
    $current_account->save();
  }

}
